==> ugene_1.20.0%2Bdfsg.orig.tar.xz: ugene-1.20.0/src/plugins/GUITestBase/src/tests/common_scenarios/sequence_view/GTTestsSequenceView.h <==
/**
 * UGENE - Integrated Bioinformatics Tools.
 * Copyright (C) 2008-2015 UniPro <ugene@unipro.ru>
 * http://ugene.unipro.ru
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA 02110-1301, USA.
 */

#ifndef _U2_GUI_TEST_SEQUENCE_VIEW_H_
#define _U2_GUI_TEST_SEQUENCE_VIEW_H_

#include <U2Test/GUITestBase.h>

namespace U2 {

namespace GUITest_common_scenarios_sequence_view {
#undef GUI_TEST_SUITE
#define GUI_TEST_SUITE "GUITest_common_scenarios_sequence_view"

GUI_TEST_CLASS_DECLARATION(test_0002)
GUI_TEST_CLASS_DECLARATION(test_0002_1)
GUI_TEST_CLASS_DECLARATION(test_0002_2)
GUI_TEST_CLASS_DECLARATION(test_0003)
GUI_TEST_CLASS_DECLARATION(test_0003_1)
GUI_TEST_CLASS_DECLARATION(test_0003_2)
GUI_TEST_CLASS_DECLARATION(test_0004)
GUI_TEST_CLASS_DECLARATION(test_0004_1)
GUI_TEST_CLASS_DECLARATION(test_0005)
GUI_TEST_CLASS_DECLARATION(test_0006)
GUI_TEST_CLASS_DECLARATION_SET_TIMEOUT(test_0006_1, 720000)
GUI_TEST_CLASS_DECLARATION(test_0006_2)

GUI_TEST_CLASS_DECLARATION(test_0018)

GUI_TEST_CLASS_DECLARATION(test_0021)
GUI_TEST_CLASS_DECLARATION(test_0022)
GUI_TEST_CLASS_DECLARATION(test_0023)
GUI_TEST_CLASS_DECLARATION(test_0024)
GUI_TEST_CLASS_DECLARATION(test_0025)
GUI_TEST_CLASS_DECLARATION(test_0026)

GUI_TEST_CLASS_DECLARATION(test_0027)
GUI_TEST_CLASS_DECLARATION(test_0028)
GUI_TEST_CLASS_DECLARATION(test_0029)
GUI_TEST_CLASS_DECLARATION(test_0030)
GUI_TEST_CLASS_DECLARATION(test_0031)
GUI_TEST_CLASS_DECLARATION(test_0031_1)
GUI_TEST_CLASS_DECLARATION(test_0031_2)
GUI_TEST_CLASS_DECLARATION(test_0031_3)
GUI_TEST_CLASS_DECLARATION(test_0032)
GUI_TEST_CLASS_DECLARATION(test_0034)
GUI_TEST_CLASS_DECLARATION(test_0035)
GUI_TEST_CLASS_DECLARATION(test_0036)
GUI_TEST_CLASS_DECLARATION(test_0037)
GUI_TEST_CLASS_DECLARATION(test_0037_1)
GUI_TEST_CLASS_DECLARATION(test_0038)
GUI_TEST_CLASS_DECLARATION(test_0040)
GUI_TEST_CLASS_DECLARATION(test_0041)
GUI_TEST_CLASS_DECLARATION(test_0042)
GUI_TEST_CLASS_DECLARATION(test_0043)
GUI_TEST_CLASS_DECLARATION(test_0044)
GUI_TEST_CLASS_DECLARATION(test_0044_1)
GUI_TEST_CLASS_DECLARATION(test_0044_2)
GUI_TEST_CLASS_DECLARATION(test_0045)
GUI_TEST_CLASS_DECLARATION(test_0046)
GUI_TEST_CLASS_DECLARATION(test_0047)
GUI_TEST_CLASS_DECLARATION(test_0048)
GUI_TEST_CLASS_DECLARATION(test_0050)
GUI_TEST_CLASS_DECLARATION(test_0050_1)
GUI_TEST_CLASS_DECLARATION(test_0051)
GUI_TEST_CLASS_DECLARATION(test_0052)
GUI_TEST_CLASS_DECLARATION(test_0052_1)
GUI_TEST_CLASS_DECLARATION(test_0053)
GUI_TEST_CLASS_DECLARATION(test_0054)
GUI_TEST_CLASS_DECLARATION(test_0055)
GUI_TEST_CLASS_DECLARATION(test_0056)
GUI_TEST_CLASS_DECLARATION(test_0057)
GUI_TEST_CLASS_DECLARATION(test_0058)
GUI_TEST_CLASS_DECLARATION(test_0059)
GUI_TEST_CLASS_DECLARATION(test_0059_1)
GUI_TEST_CLASS_DECLARATION(test_0060)
GUI_TEST_CLASS_DECLARATION(test_0061_1)
GUI_TEST_CLASS_DECLARATION(test_0061_2)
GUI_TEST_CLASS_DECLARATION(test_0061_3)

GUI_TEST_CLASS_DECLARATION(test_0062)
GUI_TEST_CLASS_DECLARATION(test_0063)
GUI_TEST_CLASS_DECLARATION(test_0064)
GUI_TEST_CLASS_DECLARATION(test_0065)
GUI_TEST_CLASS_DECLARATION(test_0066)
GUI_TEST_CLASS_DECLARATION(test_0067)
GUI_TEST_CLASS_DECLARATION(test_0068)
GUI_TEST_CLASS_DECLARATION(test_0069)
GUI_TEST_CLASS_DECLARATION(test_0070)
GUI_TEST_CLASS_DECLARATION(test_0071)


#undef GUI_TEST_SUITE
}

} //namespace

#endif

==> ugene_1.25.0%2Bdfsg.orig.tar.xz: ugene-1.25.0/src/plugins/GUITestBase/src/tests/common_scenarios/sequence_view/GTTestsSequenceView.h <==
/**
 * UGENE - Integrated Bioinformatics Tools.
 * Copyright (C) 2008-2016 UniPro <ugene@unipro.ru>
 * http://ugene.net
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA 02110-1301, USA.
 */

#ifndef _U2_GUI_TEST_SEQUENCE_VIEW_H_
#define _U2_GUI_TEST_SEQUENCE_VIEW_H_

#include <U2Test/UGUITestBase.h>

namespace U2 {

namespace GUITest_common_scenarios_sequence_view {
#undef GUI_TEST_SUITE
#define GUI_TEST_SUITE "GUITest_common_scenarios_sequence_view"

GUI_TEST_CLASS_DECLARATION(test_0002)
GUI_TEST_CLASS_DECLARATION(test_0002_1)
GUI_TEST_CLASS_DECLARATION(test_0002_2)
GUI_TEST_CLASS_DECLARATION(test_0003)
GUI_TEST_CLASS_DECLARATION(test_0003_1)
GUI_TEST_CLASS_DECLARATION(test_0003_2)
GUI_TEST_CLASS_DECLARATION(test_0004)
GUI_TEST_CLASS_DECLARATION(test_0004_1)
GUI_TEST_CLASS_DECLARATION(test_0005)
GUI_TEST_CLASS_DECLARATION(test_0006)
GUI_TEST_CLASS_DECLARATION_SET_TIMEOUT(test_0006_1, 720000)
GUI_TEST_CLASS_DECLARATION(test_0006_2)

GUI_TEST_CLASS_DECLARATION(test_0018)

GUI_TEST_CLASS_DECLARATION(test_0021)
GUI_TEST_CLASS_DECLARATION(test_0022)
GUI_TEST_CLASS_DECLARATION(test_0023)
GUI_TEST_CLASS_DECLARATION(test_0024)
GUI_TEST_CLASS_DECLARATION(test_0025)
GUI_TEST_CLASS_DECLARATION(test_0026)

GUI_TEST_CLASS_DECLARATION(test_0027)
GUI_TEST_CLASS_DECLARATION(test_0028)
GUI_TEST_CLASS_DECLARATION(test_0029)
GUI_TEST_CLASS_DECLARATION(test_0030)
GUI_TEST_CLASS_DECLARATION(test_0031)
GUI_TEST_CLASS_DECLARATION(test_0031_1)
GUI_TEST_CLASS_DECLARATION(test_0031_2)
GUI_TEST_CLASS_DECLARATION(test_0031_3)
GUI_TEST_CLASS_DECLARATION(test_0032)
GUI_TEST_CLASS_DECLARATION(test_0034)
GUI_TEST_CLASS_DECLARATION(test_0035)
GUI_TEST_CLASS_DECLARATION(test_0036)
GUI_TEST_CLASS_DECLARATION(test_0037)
GUI_TEST_CLASS_DECLARATION(test_0037_1)
GUI_TEST_CLASS_DECLARATION(test_0038)
GUI_TEST_CLASS_DECLARATION(test_0040)
GUI_TEST_CLASS_DECLARATION(test_0041)
GUI_TEST_CLASS_DECLARATION(test_0042)
GUI_TEST_CLASS_DECLARATION(test_0043)
GUI_TEST_CLASS_DECLARATION(test_0044)
GUI_TEST_CLASS_DECLARATION(test_0044_1)
GUI_TEST_CLASS_DECLARATION(test_0044_2)
GUI_TEST_CLASS_DECLARATION(test_0045)
GUI_TEST_CLASS_DECLARATION(test_0046)
GUI_TEST_CLASS_DECLARATION(test_0047)
GUI_TEST_CLASS_DECLARATION(test_0048)
GUI_TEST_CLASS_DECLARATION(test_0050)
GUI_TEST_CLASS_DECLARATION(test_0050_1)
GUI_TEST_CLASS_DECLARATION(test_0051)
GUI_TEST_CLASS_DECLARATION(test_0052)
GUI_TEST_CLASS_DECLARATION(test_0052_1)
GUI_TEST_CLASS_DECLARATION(test_0053)
GUI_TEST_CLASS_DECLARATION(test_0054)
GUI_TEST_CLASS_DECLARATION(test_0055)
GUI_TEST_CLASS_DECLARATION(test_0056)
GUI_TEST_CLASS_DECLARATION(test_0057)
GUI_TEST_CLASS_DECLARATION(test_0058)
GUI_TEST_CLASS_DECLARATION(test_0059)
GUI_TEST_CLASS_DECLARATION(test_0059_1)
GUI_TEST_CLASS_DECLARATION(test_0060)
GUI_TEST_CLASS_DECLARATION(test_0061_1)
GUI_TEST_CLASS_DECLARATION(test_0061_2)
GUI_TEST_CLASS_DECLARATION(test_0061_3)

GUI_TEST_CLASS_DECLARATION(test_0062)
GUI_TEST_CLASS_DECLARATION(test_0063)
GUI_TEST_CLASS_DECLARATION(test_0064)
GUI_TEST_CLASS_DECLARATION(test_0065)
GUI_TEST_CLASS_DECLARATION(test_0066)
GUI_TEST_CLASS_DECLARATION(test_0067)
GUI_TEST_CLASS_DECLARATION(test_0068)
GUI_TEST_CLASS_DECLARATION(test_0069)
GUI_TEST_CLASS_DECLARATION(test_0070)
GUI_TEST_CLASS_DECLARATION(test_0071)
GUI_TEST_CLASS_DECLARATION(test_0075)
GUI_TEST_CLASS_DECLARATION(test_0076)
GUI_TEST_CLASS_DECLARATION(test_0077)
GUI_TEST_CLASS_DECLARATION(test_0078)

#undef GUI_TEST_SUITE
}

} //namespace

#endif
